==> kubernetes-model-gatewayapi-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRouteFluentImpl<A extends HTTPRouteFluent<A>> extends BaseFluent<A> implements HTTPRouteFluent<A>{
  public HTTPRouteFluentImpl() {
  }
  public HTTPRouteFluentImpl(HTTPRoute instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private HTTPRouteSpecBuilder spec;
  private HTTPRouteStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public HTTPRouteFluent.MetadataNested<A> withNewMetadata() {
    return new HTTPRouteFluentImpl.MetadataNestedImpl();
  }
  public HTTPRouteFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new HTTPRouteFluentImpl.MetadataNestedImpl(item);
  }
  public HTTPRouteFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public HTTPRouteFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public HTTPRouteFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRouteSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public HTTPRouteSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(HTTPRouteSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new HTTPRouteSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public HTTPRouteFluent.SpecNested<A> withNewSpec() {
    return new HTTPRouteFluentImpl.SpecNestedImpl();
  }
  public HTTPRouteFluent.SpecNested<A> withNewSpecLike(HTTPRouteSpec item) {
    return new HTTPRouteFluentImpl.SpecNestedImpl(item);
  }
  public HTTPRouteFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public HTTPRouteFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new HTTPRouteSpecBuilder().build());
  }
  public HTTPRouteFluent.SpecNested<A> editOrNewSpecLike(HTTPRouteSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRouteStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public HTTPRouteStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(HTTPRouteStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new HTTPRouteStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public HTTPRouteFluent.StatusNested<A> withNewStatus() {
    return new HTTPRouteFluentImpl.StatusNestedImpl();
  }
  public HTTPRouteFluent.StatusNested<A> withNewStatusLike(HTTPRouteStatus item) {
    return new HTTPRouteFluentImpl.StatusNestedImpl(item);
  }
  public HTTPRouteFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public HTTPRouteFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new HTTPRouteStatusBuilder().build());
  }
  public HTTPRouteFluent.StatusNested<A> editOrNewStatusLike(HTTPRouteStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPRouteFluentImpl that = (HTTPRouteFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<HTTPRouteFluent.MetadataNested<N>> implements HTTPRouteFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) HTTPRouteFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends HTTPRouteSpecFluentImpl<HTTPRouteFluent.SpecNested<N>> implements HTTPRouteFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(HTTPRouteSpec item) {
      this.builder = new HTTPRouteSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new HTTPRouteSpecBuilder(this);
    }
    HTTPRouteSpecBuilder builder;
    public N and() {
      return (N) HTTPRouteFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends HTTPRouteStatusFluentImpl<HTTPRouteFluent.StatusNested<N>> implements HTTPRouteFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(HTTPRouteStatus item) {
      this.builder = new HTTPRouteStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new HTTPRouteStatusBuilder(this);
    }
    HTTPRouteStatusBuilder builder;
    public N and() {
      return (N) HTTPRouteFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRouteFluentImpl<A extends HTTPRouteFluent<A>> extends BaseFluent<A> implements HTTPRouteFluent<A>{
  public HTTPRouteFluentImpl() {
  }
  public HTTPRouteFluentImpl(HTTPRoute instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private HTTPRouteSpecBuilder spec;
  private HTTPRouteStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public HTTPRouteFluentImpl.MetadataNested<A> withNewMetadata() {
    return new HTTPRouteFluentImpl.MetadataNestedImpl();
  }
  public HTTPRouteFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new HTTPRouteFluentImpl.MetadataNestedImpl(item);
  }
  public HTTPRouteFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public HTTPRouteFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public HTTPRouteFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRouteSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public HTTPRouteSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(HTTPRouteSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new HTTPRouteSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public HTTPRouteFluentImpl.SpecNested<A> withNewSpec() {
    return new HTTPRouteFluentImpl.SpecNestedImpl();
  }
  public HTTPRouteFluentImpl.SpecNested<A> withNewSpecLike(HTTPRouteSpec item) {
    return new HTTPRouteFluentImpl.SpecNestedImpl(item);
  }
  public HTTPRouteFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public HTTPRouteFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new HTTPRouteSpecBuilder().build());
  }
  public HTTPRouteFluentImpl.SpecNested<A> editOrNewSpecLike(HTTPRouteSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPRouteStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public HTTPRouteStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(HTTPRouteStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new HTTPRouteStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public HTTPRouteFluentImpl.StatusNested<A> withNewStatus() {
    return new HTTPRouteFluentImpl.StatusNestedImpl();
  }
  public HTTPRouteFluentImpl.StatusNested<A> withNewStatusLike(HTTPRouteStatus item) {
    return new HTTPRouteFluentImpl.StatusNestedImpl(item);
  }
  public HTTPRouteFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public HTTPRouteFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new HTTPRouteStatusBuilder().build());
  }
  public HTTPRouteFluentImpl.StatusNested<A> editOrNewStatusLike(HTTPRouteStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRouteFluentImpl that = (HTTPRouteFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<HTTPRouteFluentImpl.MetadataNested<N>> implements HTTPRouteFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) HTTPRouteFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends HTTPRouteSpecFluentImpl<HTTPRouteFluentImpl.SpecNested<N>> implements HTTPRouteFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(HTTPRouteSpec item) {
      this.builder = new HTTPRouteSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new HTTPRouteSpecBuilder(this);
    }
    HTTPRouteSpecBuilder builder;
    public N and() {
      return (N) HTTPRouteFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends HTTPRouteStatusFluentImpl<HTTPRouteFluentImpl.StatusNested<N>> implements HTTPRouteFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(HTTPRouteStatus item) {
      this.builder = new HTTPRouteStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new HTTPRouteStatusBuilder(this);
    }
    HTTPRouteStatusBuilder builder;
    public N and() {
      return (N) HTTPRouteFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
